summaryrefslogtreecommitdiff
path: root/packages/taler-wallet-core/src/db.ts
diff options
context:
space:
mode:
authorFlorian Dold <florian@dold.me>2023-08-03 18:35:07 +0200
committerFlorian Dold <florian@dold.me>2023-08-03 18:35:07 +0200
commitfdbd55d2bde0961a4c1ff26b04e442459ab782b0 (patch)
treed0d04f42a5477f6d7d39a8940d59ff1548166711 /packages/taler-wallet-core/src/db.ts
parent0fe4840ca2612dda06417cdebe5229eea98180be (diff)
downloadwallet-core-fdbd55d2bde0961a4c1ff26b04e442459ab782b0.tar.gz
wallet-core-fdbd55d2bde0961a4c1ff26b04e442459ab782b0.tar.bz2
wallet-core-fdbd55d2bde0961a4c1ff26b04e442459ab782b0.zip
-towards tip->reward rename
Diffstat (limited to 'packages/taler-wallet-core/src/db.ts')
-rw-r--r--packages/taler-wallet-core/src/db.ts58
1 files changed, 21 insertions, 37 deletions
diff --git a/packages/taler-wallet-core/src/db.ts b/packages/taler-wallet-core/src/db.ts
index 6a7a26f2f..3d2878d93 100644
--- a/packages/taler-wallet-core/src/db.ts
+++ b/packages/taler-wallet-core/src/db.ts
@@ -677,7 +677,7 @@ export interface PlanchetRecord {
export enum CoinSourceType {
Withdraw = "withdraw",
Refresh = "refresh",
- Tip = "tip",
+ Reward = "reward",
}
export interface WithdrawCoinSource {
@@ -705,13 +705,13 @@ export interface RefreshCoinSource {
oldCoinPub: string;
}
-export interface TipCoinSource {
- type: CoinSourceType.Tip;
- walletTipId: string;
+export interface RewardCoinSource {
+ type: CoinSourceType.Reward;
+ walletRewardId: string;
coinIndex: number;
}
-export type CoinSource = WithdrawCoinSource | RefreshCoinSource | TipCoinSource;
+export type CoinSource = WithdrawCoinSource | RefreshCoinSource | RewardCoinSource;
/**
* CoinRecord as stored in the "coins" data store
@@ -815,9 +815,9 @@ export interface CoinAllocation {
}
/**
* Status of a tip we got from a merchant.
*/
-export interface TipRecord {
+export interface RewardRecord {
/**
* Has the user accepted the tip? Only after the tip has been accepted coins
* withdrawn from the tip may be used.
@@ -827,17 +827,17 @@ export interface TipRecord {
/**
* The tipped amount.
*/
- tipAmountRaw: AmountString;
+ rewardAmountRaw: AmountString;
/**
* Effect on the balance (including fees etc).
*/
- tipAmountEffective: AmountString;
+ rewardAmountEffective: AmountString;
/**
* Timestamp, the tip can't be picked up anymore after this deadline.
*/
- tipExpiration: TalerProtocolTimestamp;
+ rewardExpiration: TalerProtocolTimestamp;
/**
* The exchange that will sign our coins, chosen by the merchant.
@@ -863,7 +863,7 @@ export interface TipRecord {
/**
* Tip ID chosen by the wallet.
*/
- walletTipId: string;
+ walletRewardId: string;
/**
* Secret seed used to derive planchets for this tip.
@@ -871,9 +871,9 @@ export interface TipRecord {
secretSeed: string;
/**
* The merchant's identifier for this tip.
*/
- merchantTipId: string;
+ merchantRewardId: string;
createdTimestamp: TalerPreciseTimestamp;
@@ -888,10 +888,10 @@ export interface TipRecord {
*/
pickedUpTimestamp: TalerPreciseTimestamp | undefined;
- status: TipRecordStatus;
+ status: RewardRecordStatus;
}
-export enum TipRecordStatus {
+export enum RewardRecordStatus {
PendingPickup = 10,
SuspendidPickup = 20,
@@ -1420,7 +1420,7 @@ export interface KycPendingInfo {
}
/**
* Group of withdrawal operations that need to be executed.
* (Either for a normal withdrawal or from a tip.)
*
* The withdrawal group record is only created after we know
* the coin selection we want to withdraw.
@@ -2480,12 +2480,12 @@ export const WalletStoresV1 = {
]),
},
),
- tips: describeStore(
- "tips",
- describeContents<TipRecord>({ keyPath: "walletTipId" }),
+ rewards: describeStore(
+ "rewards",
+ describeContents<RewardRecord>({ keyPath: "walletRewardId" }),
{
- byMerchantTipIdAndBaseUrl: describeIndex("byMerchantTipIdAndBaseUrl", [
- "merchantTipId",
+ byMerchantTipIdAndBaseUrl: describeIndex("byMerchantRewardIdAndBaseUrl", [
+ "merchantRewardId",
"merchantBaseUrl",
]),
byStatus: describeIndex("byStatus", "status", {
@@ -2936,22 +2936,6 @@ export const walletDbFixups: FixupDescription[] = [
},
},
{
- name: "TipRecordRecord_status_add",
- async fn(tx): Promise<void> {
- await tx.tips.iter().forEachAsync(async (r) => {
- // Remove legacy transactions that don't have the totalCost field yet.
- if (r.status == null) {
- if (r.pickedUpTimestamp) {
- r.status = TipRecordStatus.Done;
- } else {
- r.status = TipRecordStatus.PendingPickup;
- }
- await tx.tips.put(r);
- }
- });
- },
- },
- {
name: "CoinAvailabilityRecord_visibleCoinCount_add",
async fn(tx): Promise<void> {
await tx.coinAvailability.iter().forEachAsync(async (r) => {
@@ -815,9 +815,9 @@ export interface CoinAllocation {
}
/**
- * Status of a tip we got from a merchant.
+ * Status of a reward we got from a merchant.
*/
@@ -871,9 +871,9 @@ export interface TipRecord {
secretSeed: string;
/**
- * The merchant's identifier for this tip.
+ * The merchant's identifier for this reward.
*/
@@ -1420,7 +1420,7 @@ export interface KycPendingInfo {
/**
* Group of withdrawal operations that need to be executed.
- * (Either for a normal withdrawal or from a tip.)
+ * (Either for a normal withdrawal or from a reward.)
*
* The withdrawal group record is only created after we know